@@ -60,7 +60,7 @@ DocGuardedPtr DocumentMan::copyDocument( const QString& copyFromId )
 DocGuardedPtr DocumentMan::createDocument( const QString& docType, const QString& copyFromId, const DocPositionList& listToCopy)
 {
     DocGuardedPtr doc = new KraftDoc();
-    // qDebug () << "new document ID: " << doc->docID().toString() << endl;
+    // qDebug () << "new document ID: " << doc->docID().toString();
 
     if ( ! copyFromId.isEmpty() ) {
         // copy the content from the source document to the new doc.
@@ -101,23 +101,23 @@ DocGuardedPtr DocumentMan::createDocument( const QString& docType, const QString
             // Take the default pre- and posttext for the new docType, or, if that is empty, the texts of the old doc
             QString newText = DefaultProvider::self()->defaultText( docType, KraftDoc::Header );
             if (newText.isEmpty() ) {
-                newText = sourceDoc->preText();
+                newText = sourceDoc->preTextRaw();
             }
-            doc->setPreText(newText);
+            doc->setPreTextRaw(newText);
 
             newText = DefaultProvider::self()->defaultText( docType, KraftDoc::Footer );
             if (newText.isEmpty() ) {
-                newText = sourceDoc->postText();
+                newText = sourceDoc->postTextRaw();
             }
-            doc->setPostText(newText);
+            doc->setPostTextRaw(newText);
 
             delete sourceDoc;
         }
     } else {
         // Absolute new document
         doc->setDocType(docType);
-        doc->setPreText(DefaultProvider::self()->defaultText(docType, KraftDoc::Header));
-        doc->setPostText(DefaultProvider::self()->defaultText(docType, KraftDoc::Footer));
+        doc->setPreTextRaw(DefaultProvider::self()->defaultText(docType, KraftDoc::Header));
+        doc->setPostTextRaw(DefaultProvider::self()->defaultText(docType, KraftDoc::Footer));
         doc->setGoodbye( KraftSettings::greeting() );
     }
 
@@ -142,7 +142,7 @@ DocGuardedPtr DocumentMan::openDocumentbyIdent( const QString& ident )
 
 DocGuardedPtr DocumentMan::openDocument( const QString& id )
 {
-  // qDebug () << "Opening Document with id " << id << endl;
+  // qDebug () << "Opening Document with id " << id;
   DocGuardedPtr doc = new KraftDoc();
   doc->openDocument( id );
   return doc;
