@@ -74,6 +74,7 @@
 #include "addressprovider.h"
 #include "addressselectordialog.h"
 #include "format.h"
+#include "stringutil.h"
 
 #define NO_TAX   0
 #define RED_TAX  1
@@ -119,28 +120,22 @@ KraftView::KraftView(QWidget *parent) :
   mViewStack = new QStackedWidget;
   mCSplit->addWidget( mViewStack );
 
-  // qDebug () << "mViewSTack height is " << mViewStack->height() << endl;
+  // qDebug () << "mViewSTack height is " << mViewStack->height();
 
   mAssistant = new DocAssistant( mCSplit );
   mCSplit->addWidget( mAssistant );
 
   /* catalog template selection signal */
-  connect(mAssistant, &DocAssistant::templatesToDocument,
-          this, &KraftView::slotAddItems);
+  connect(mAssistant, &DocAssistant::templatesToDocument, this, &KraftView::slotAddItems);
 
   /* signal to toggle the visibility of the template section in the assistant */
-  connect(  mAssistant, SIGNAL( toggleShowTemplates( bool ) ),
-            this,  SLOT( slotShowTemplates( bool ) ) );
+  connect(mAssistant, &DocAssistant::toggleShowTemplates, this, &KraftView::slotShowTemplates);
 
   /* signal that brings a new address to the document */
-  connect( mAssistant, SIGNAL( headerTextTemplate( const QString& ) ),
-           this, SLOT( slotNewHeaderText( const QString& ) ) );
+  connect(mAssistant, &DocAssistant::headerTextTemplate, this, &KraftView::slotNewHeaderText);
+  connect(mAssistant, &DocAssistant::footerTextTemplate, this, &KraftView::slotNewFooterText);
 
-  connect( mAssistant, SIGNAL( footerTextTemplate( const QString& ) ),
-           this, SLOT( slotNewFooterText( const QString& ) ) );
-
-  connect( mAssistant, SIGNAL( selectPage( int ) ),
-           this,  SLOT( slotSwitchToPage( int ) ) );
+  connect(mAssistant, &DocAssistant::selectPage, this, &KraftView::slotSwitchToPage);
 
   mAssistant->slotSelectDocPart( KraftDoc::Header );
 
@@ -159,7 +154,7 @@ KraftView::KraftView(QWidget *parent) :
 
 KraftView::~KraftView()
 {
-    // qDebug () << "KRAFTVIEW going away." << endl;
+    // qDebug () << "KRAFTVIEW going away.";
 }
 
 void KraftView::setupMappers()
@@ -306,9 +301,9 @@ void KraftView::redrawDocument( )
 {
     KraftDoc *doc = getDocument();
     if( !doc ) {
-      // qDebug () << "ERR: No document available in view, return!" << endl;
+      // qDebug () << "ERR: No document available in view, return!";
     } else {
-      // qDebug () << "** Starting redraw of document " << doc << endl;
+      // qDebug () << "** Starting redraw of document " << doc;
     }
 
     /* header: date and document type */
@@ -320,14 +315,14 @@ void KraftView::redrawDocument( )
     mContactUid  = doc->addressUid();
     QString address = doc->address();
 
-    // qDebug () << "Loaded address uid from database " << mContactUid << endl;
+    // qDebug () << "Loaded address uid from database " << mContactUid;
     if( ! mContactUid.isEmpty() ) {
       mAddressProvider->lookupAddressee( mContactUid );
     }
 
     if( !address.isEmpty() ) {
       // custom address stored in the document.
-      // qDebug() << "custom address came in: " << address << endl;
+      // qDebug() << "custom address came in: " << address;
       m_headerEdit->m_postAddressEdit->setText( address );
     }
 
@@ -336,10 +331,10 @@ void KraftView::redrawDocument( )
       m_headerEdit->m_letterHead->setCurrentIndex(m_headerEdit->m_letterHead->findText( doc->salut() ));
     }
     /* pre- and post text */
-    m_headerEdit->m_teEntry->setPlainText( doc->preText() );
+    m_headerEdit->m_teEntry->setPlainText( doc->preTextRaw() );
     m_headerEdit->m_whiteboardEdit->setPlainText( doc->whiteboard() );
     m_headerEdit->mProjectLabelEdit->setText( doc->projectLabel() );
-    m_footerEdit->ui()->m_teSummary->setPlainText( doc->postText() );
+    m_footerEdit->ui()->m_teSummary->setPlainText( doc->postTextRaw() );
     const QString goodbye = doc->goodbye();
     m_footerEdit->slotSetGreeting(goodbye);
 
@@ -476,7 +471,7 @@ void KraftView::redrawDocPositions( )
       w->slotAllowIndividualTax( currentTaxSetting() == DocPositionBase::TaxIndividual );
     }
     cnt++;
-    // qDebug () << "now position " << dp->positionNumber() << endl;
+    // qDebug () << "now position " << dp->positionNumber();
   }
 
   // now go through the positionWidgetMap and check if it contains elements
@@ -487,7 +482,7 @@ void KraftView::redrawDocPositions( )
     PositionViewWidget *w = it2.next();
 
     if( w && (list.contains( w->position() ) == 0) ) {
-      // qDebug () << "Removing this one: " << w << endl;
+      // qDebug () << "Removing this one: " << w;
       m_positionScroll->removeChild( w );
       it2.remove();
       // mPositionWidgetList.erase( it2 );
@@ -582,23 +577,30 @@ void KraftView::refreshPostCard()
 {
   DocPositionList positions = currentPositionList();
 
-  if( !getDocument() ) return;
+  KraftDoc *kraftDoc = getDocument();
+  if( !kraftDoc) return;
 
   if ( mAssistant->postCard() ) {
     QDate d = m_headerEdit->m_dateEdit->date();
     const QString dStr = Format::toDateString( d, KraftSettings::self()->dateFormat() );
 
+    double fullTax = DocumentMan::self()->tax(d);
+    double redTax = DocumentMan::self()->reducedTax(d);
+    const QString preText = kraftDoc->resolveMacros(m_headerEdit->m_teEntry->toPlainText(),
+                                                    positions, d, fullTax, redTax);
+    const QString postText = kraftDoc->resolveMacros(m_footerEdit->ui()->m_teSummary->toPlainText(),
+                                                     positions, d, fullTax, redTax);
     mAssistant->postCard()->setHeaderData( m_headerEdit->m_cbType->currentText(),
                                            dStr, m_headerEdit->m_postAddressEdit->toPlainText(),
                                            getDocument()->ident(),
-                                           m_headerEdit->m_teEntry->toPlainText() );
+                                           preText );
 
 
     mAssistant->postCard()->setPositions( positions,  currentTaxSetting(),
                                           DocumentMan::self()->tax( d ),
                                           DocumentMan::self()->reducedTax( d ) );
 
-    mAssistant->postCard()->setFooterData( m_footerEdit->ui()->m_teSummary->toPlainText(),
+    mAssistant->postCard()->setFooterData( postText,
                                            m_footerEdit->greeting() );
 
     mAssistant->postCard()->renderDoc( mViewStack->currentIndex() ); // id( mViewStack->visibleWidget() ) );
@@ -615,7 +617,7 @@ void KraftView::refreshPostCard()
       if( w ) {
         w->slotSetOverallPrice( ( static_cast<DocPosition*>( dp ) )->overallPrice() );
       } else {
-        // qDebug () << "Warning: Position object has no associated widget!" << endl;
+        // qDebug () << "Warning: Position object has no associated widget!";
       }
     }
   }
@@ -728,9 +730,9 @@ void KraftView::slotMovePositionUp( int pos )
   PositionViewWidget *w1 = nullptr;
   PositionViewWidget *w2 = nullptr;
 
-  // qDebug () << "Moving position up: " << pos << endl;
+  // qDebug () << "Moving position up: " << pos;
   if( pos < 1 || pos > mPositionWidgetList.count() ) {
-    // qDebug () << "ERR: position out of range: " << pos << endl;
+    // qDebug () << "ERR: position out of range: " << pos;
     return;
   }
 
@@ -738,10 +740,10 @@ void KraftView::slotMovePositionUp( int pos )
   w1 = mPositionWidgetList.at( pos-1 );
   w2 = mPositionWidgetList.at( pos ); // Porting ATTENTION: check assignment of w1, w1
 
-  // qDebug () << "Found at pos " << pos << " the widgets " << w1 << " and " << w2 << endl;
+  // qDebug () << "Found at pos " << pos << " the widgets " << w1 << " and " << w2;
 
   if( w1 && w2 ) {
-    // qDebug () << "Setting ord number: " << pos << endl;
+    // qDebug () << "Setting ord number: " << pos;
     w1->setOrdNumber( pos );  // note: ordnumbers start with 1, thus add one
     w2->setOrdNumber( pos+1 );
     setMappingId( w1, pos-1 );
@@ -751,7 +753,7 @@ void KraftView::slotMovePositionUp( int pos )
     mModified = true;
     QTimer::singleShot( 0, this, SLOT(refreshPostCard()  ) );
   } else {
-    // qDebug () << "ERR: Did not find the two corresponding widgets!" << endl;
+    // qDebug () << "ERR: Did not find the two corresponding widgets!";
   }
 }
 /*
@@ -764,10 +766,10 @@ void KraftView::slotMovePositionDown( int pos )
 {
   PositionViewWidget *w1 = nullptr;
   PositionViewWidget *w2 = nullptr;
-  // qDebug () << "Moving position down: " << pos << endl;
+  // qDebug () << "Moving position down: " << pos;
 
   if( pos < 0 || pos >= mPositionWidgetList.count() -1 ) {
-    // qDebug () << "ERR: position out of range: " << pos << endl;
+    // qDebug () << "ERR: position out of range: " << pos;
     return;
   }
 
@@ -787,7 +789,7 @@ void KraftView::slotMovePositionDown( int pos )
     mModified = true;
     QTimer::singleShot( 0, this, SLOT( refreshPostCard() ) );
   } else {
-    // qDebug () << "ERR: Did not find the two corresponding widgets!" << endl;
+    // qDebug () << "ERR: Did not find the two corresponding widgets!";
   }
 }
 
@@ -802,7 +804,7 @@ void KraftView::slotDeletePosition( int pos )
 
 void KraftView::slotLockPosition( int pos )
 {
-  // qDebug () << "Locking Position " << pos << endl;
+  // qDebug () << "Locking Position " << pos;
 
   PositionViewWidget *w1 = mPositionWidgetList.at( pos );
   if( w1 ) {
@@ -813,7 +815,7 @@ void KraftView::slotLockPosition( int pos )
 
 void KraftView::slotUnlockPosition( int pos )
 {
-  // qDebug () << "Unlocking Position " << pos << endl;
+  // qDebug () << "Unlocking Position " << pos;
 
   PositionViewWidget *w1 = mPositionWidgetList.at( pos );
   if( w1 ) {
@@ -824,7 +826,7 @@ void KraftView::slotUnlockPosition( int pos )
 
 void KraftView::slotPositionModified( int )
 {
-    // qDebug () << "Modified Position " << pos << endl;
+    // qDebug () << "Modified Position " << pos;
     mModified = true;
 
     QTimer::singleShot( 0, this, SLOT( refreshPostCard() ) );
@@ -877,7 +879,7 @@ void KraftView::slotAddressFound(const QString& uid, const KContacts::Addressee&
 
 void KraftView::slotDocTypeChanged( const QString& newType )
 {
-  // qDebug () << "Doc Type changed to " << newType << endl;
+  // qDebug () << "Doc Type changed to " << newType;
   mAssistant->slotSetDocType( newType );
 
   DocType docType( newType );
@@ -901,19 +903,27 @@ void KraftView::slotDocTypeChanged( const QString& newType )
 
 void KraftView::slotLanguageSettings()
 {
-  // qDebug () << "Language Settings" << endl;
+  // qDebug () << "Language Settings";
   // FIXME 
 }
 
-void KraftView::slotNewHeaderText( const QString& str )
+void KraftView::slotNewHeaderText( const DocText& dt, bool replace )
 {
-  m_headerEdit->m_teEntry->setText( str );
-  slotModifiedHeader();
+    if (replace) {
+        m_headerEdit->m_teEntry->setPlainText( dt.text());
+    } else {
+        m_headerEdit->m_teEntry->insertPlainText(dt.text());
+    }
+    slotModifiedHeader();
 }
 
-void KraftView::slotNewFooterText( const QString& str )
+void KraftView::slotNewFooterText( const DocText& dt, bool replace )
 {
-  m_footerEdit->ui()->m_teSummary->setText( str );
+  if (replace) {
+      m_footerEdit->ui()->m_teSummary->setPlainText(dt.text());
+  } else {
+      m_footerEdit->ui()->m_teSummary->insertPlainText(dt.text());
+  }
   slotModifiedFooter();
 }
 
@@ -928,7 +938,6 @@ void KraftView::slotAddNewItem()
 
 void KraftView::slotAddItems( Katalog *kat, CatalogTemplateList templates, const QString& selectedChapter)
 {
-
     if(templates.count() == 0) {
         slotAddItem(kat, nullptr, selectedChapter);
     } else {
@@ -942,7 +951,7 @@ void KraftView::slotAddItem( Katalog *kat, CatalogTemplate *tmpl, const QString&
 {
     // newpos is a list position, starts counting at zero!
     int newpos = mPositionWidgetList.count();
-    // qDebug () << "Adding Position at list position " << newpos << endl;
+    // qDebug () << "Adding Position at list position " << newpos;
 
     QScopedPointer<TemplToPositionDialogBase> dia;
 
@@ -1095,7 +1104,7 @@ void KraftView::slotAddExtraPosition()
 {
   // newpos is a list position, starts counting at 0
   int newpos = mPositionWidgetList.count();
-  // qDebug () << "Adding EXTRA Position at position " << newpos << endl;
+  // qDebug () << "Adding EXTRA Position at position " << newpos;
 
   DocPosition *dp = new DocPosition( DocPosition::ExtraDiscount );
   dp->setPositionNumber( newpos+1 );
@@ -1108,10 +1117,10 @@ void KraftView::slotAddExtraPosition()
     dp->setTaxType( currentTaxSetting() );
   }
 
-  // qDebug () << "New Extra position is " << dp << endl;
+  // qDebug () << "New Extra position is " << dp;
 
   PositionViewWidget *widget = createPositionViewWidget( dp, newpos );
-  // qDebug () << "PositionViewWiget doc position is: " << widget->position() << endl;
+  // qDebug () << "PositionViewWiget doc position is: " << widget->position();
   widget->slotModified();
   slotFocusItem( widget, newpos );
   refreshPostCard();
@@ -1132,13 +1141,13 @@ DocPositionList KraftView::currentPositionList()
         // the loop runs until all positions have a valid price.
 
         int preListCnt = list.count();
-        // qDebug() << "# Pre List Count: " << preListCnt << endl;
+        // qDebug() << "# Pre List Count: " << preListCnt;
 
         while ( outerIt.hasNext() ) {
             widget = outerIt.next();
             DocPositionBase *dpb = widget->position();
 
-            KraftDB::StringMap replaceMap;
+            QMap<QString, QString> replaceMap;
 
             if ( dpb ) {
                 DocPosition *newDp = new DocPosition( dpb->type() );
@@ -1176,7 +1185,7 @@ DocPositionList KraftView::currentPositionList()
                     PositionViewWidgetListIterator it( mPositionWidgetList );
                     PositionViewWidget *w1;
                     Geld sum;
-                    // qDebug () << "Starting to loop over the items " << endl;
+                    // qDebug () << "Starting to loop over the items ";
                     while (  calculatable && it.hasNext() ) {
                         w1 = it.next();
 
@@ -1186,18 +1195,18 @@ DocPositionList KraftView::currentPositionList()
                                 if ( w1->priceValid() ) {
                                     sum += w1->currentPrice();
                                     // qDebug () << "Summing up pos with text " << w1->ordNumber() << " and price "
-                                    // << w1->currentPrice().toLong() << endl;
+                                    // << w1->currentPrice().toLong();
                                 } else {
                                     calculatable = false; // give up, we continue in outerIt
-                                    // qDebug () << "We skip pos " << w1->ordNumber() << endl;
+                                    // qDebug () << "We skip pos " << w1->ordNumber();
                                 }
                             }
                         } else {
                             // we can not calculate ourselves.
-                            // qDebug () << "Skipping pos " << w1->ordNumber() << " in summing up, thats me!" << endl;
+                            // qDebug () << "Skipping pos " << w1->ordNumber() << " in summing up, thats me!";
                         }
                     }
-                    // qDebug () << "Finished loop over items with calculatable=" << calculatable << endl;
+                    // qDebug () << "Finished loop over items with calculatable=" << calculatable;
 
                     if ( calculatable ) {
                         sum = sum.percent( discount );
@@ -1227,7 +1236,7 @@ DocPositionList KraftView::currentPositionList()
 
                     QString t = widget->m_teFloskel->toPlainText();
                     if ( !replaceMap.empty() ) {
-                        t = KraftDB::self()->replaceTagsInWord( t, replaceMap );
+                        t = StringUtil::replaceTagsInString(t, replaceMap);
                     }
                     newDp->setText( t );
 
@@ -1250,7 +1259,7 @@ DocPositionList KraftView::currentPositionList()
                     /* set Attribute with the tags */
                     const QStringList tagStrings = widget->tagList();
                     newDp->replaceTags(tagStrings);
-                    // qDebug() << "============ " << tags.toString() << endl;
+                    // qDebug() << "============ " << tags.toString();
 
                     // tax settings
                     if( currentTaxSetting() == DocPositionBase::TaxIndividual ) {
@@ -1261,13 +1270,13 @@ DocPositionList KraftView::currentPositionList()
                     list.append( newDp );
                 }
             } else {
-                qCritical() << "Fatal: Widget without position found!" << endl;
+                qCritical() << "Fatal: Widget without position found!";
             }
         }
-        // qDebug() << " Post List Count: " << list.count() << endl;
+        // qDebug() << " Post List Count: " << list.count();
 
         if ( preListCnt == list.count() ) {
-            qCritical() << "No progress in widget list processing - abort!" << endl;
+            qCritical() << "No progress in widget list processing - abort!";
             progress = false;
         }
     }
@@ -1290,13 +1299,13 @@ void KraftView::slotModifiedPositions()
         return;
     }
 
-    qDebug () << "Position Modified" << endl;
+    qDebug () << "Position Modified";
     mModified = true;
 }
 
 void KraftView::slotModifiedHeader()
 {
-    // qDebug () << "Modified the header!" << endl;
+    // qDebug () << "Modified the header!";
     // As long as the modified mapper is blocked, ignore this.
     if( mModifiedMapper->signalsBlocked() ) {
         return;
@@ -1309,7 +1318,7 @@ void KraftView::slotModifiedHeader()
 
 void KraftView::slotModifiedFooter()
 {
-    // qDebug () << "Modified the footer!" << endl;
+    // qDebug () << "Modified the footer!";
     // As long as the modified mapper is blocked, ignore this.
     if( mModifiedMapper->signalsBlocked() ) {
         return;
@@ -1324,7 +1333,7 @@ QStringList KraftView::generateLetterHead( const QString& familyName, const QStr
 {
     QStringList s;
 
-    KraftDB::StringMap m;
+    QMap<QString, QString> m;
     m[ "%NAME"]       = familyName;
     m[ "%GIVEN_NAME"] = givenName;
 
@@ -1367,12 +1376,12 @@ void KraftView::done( int r )
 
 void KraftView::saveChanges()
 {
-    // qDebug () << "Saving changes!" << endl;
+    // qDebug () << "Saving changes!";
 
     KraftDoc *doc = getDocument();
 
     if( !doc ) {
-      // qDebug () << "ERR: No document available in view, return!" << endl;
+      // qDebug () << "ERR: No document available in view, return!";
       return;
     }
     // transfer all values to the document
@@ -1380,11 +1389,11 @@ void KraftView::saveChanges()
     doc->setAddressUid( mContactUid );
     doc->setAddress(  m_headerEdit->m_postAddressEdit->toPlainText() );
     doc->setDocType(  m_headerEdit->m_cbType->currentText() );
-    doc->setPreText(  m_headerEdit->m_teEntry->toPlainText() );
+    doc->setPreTextRaw(  m_headerEdit->m_teEntry->toPlainText() );
     doc->setWhiteboard( m_headerEdit->m_whiteboardEdit->toPlainText() );
     doc->setProjectLabel( m_headerEdit->mProjectLabelEdit->text() );
     doc->setSalut(    m_headerEdit->m_letterHead->currentText() );
-    doc->setPostText( m_footerEdit->ui()->m_teSummary->toPlainText() );
+    doc->setPostTextRaw( m_footerEdit->ui()->m_teSummary->toPlainText() );
     doc->setGoodbye(  m_footerEdit->greeting() );
 
     DocPositionList list = currentPositionList();
@@ -1423,7 +1432,7 @@ void KraftView::discardChanges()
   // We need to reread the document
   KraftDoc *doc = getDocument();
   if( doc && doc->isModified() ) {
-    // qDebug () << "Document refetch from database" << endl;
+    // qDebug () << "Document refetch from database";
     doc->reloadDocument();
   }
 }
