@@ -92,6 +92,8 @@ private:
   QLineEdit *m_leName;
   QLineEdit *m_lePasswd;
   QLineEdit *_lineEditXRechnung;
+  QLineEdit *_lineEditDemandText;
+  QLineEdit *_lineEditAlternativeText;
   QLabel    *m_statusLabel;
 
   QWidget         *m_mysqlpart;
@@ -120,6 +122,10 @@ private:
   QTabWidget     *_tabWidget;
   Ui::manualOwnIdentity ui;
 
+  QLineEdit *_bacName;
+  QLineEdit *_bacIBAN;
+  QLineEdit *_bacBIC;
+
     int _maxNavBarTextWidth;
 };
 
