@@ -41,7 +41,7 @@ public:
     void reload( dbID ) override;
 
     /** No descriptions */
-    FloskelTemplateList getFlosTemplates( const CatalogChapter& chapter );
+    FloskelTemplateList getFlosTemplates( int );
 
     KatalogType type() override { return TemplateCatalog; }
 
@@ -52,8 +52,6 @@ public:
 
     int addNewTemplate( FloskelTemplate *tmpl );
 
-    void recordUsage(int id) override;
-
 public slots:
     void writeXMLFile() override;
     void deleteTemplate( int );
