@@ -66,7 +66,7 @@ void TemplKatalogListView::addCatalogDisplay( const QString& katName )
     TemplKatalog* catalog = static_cast<TemplKatalog*>(KatalogMan::self()->getKatalog(katName));
 
     if ( !catalog ) {
-        qCritical() << "Could not load catalog " << katName << endl;
+        qCritical() << "Could not load catalog " << katName;
         return;
     }
 
@@ -176,7 +176,7 @@ void TemplKatalogListView::addCalcParts( FloskelTemplate *tmpl )
         CalcPart *cp = it.next();
         QString title = cp->getName();
         QString type = cp->getType();
-        // qDebug () << "Type is " << type << endl;
+        // qDebug () << "Type is " << type;
         if( type  == KALKPART_TIME ) {
             TimeCalcPart *zcp = static_cast<TimeCalcPart*>(cp);
             StdSatz stdsatz = zcp->getStundensatz();
@@ -226,7 +226,7 @@ DocPosition TemplKatalogListView::itemToDocPosition( QTreeWidgetItem *it )
         pos.setUnit( flos->unit() );
         pos.setUnitPrice( flos->unitPrice() );
     } else {
-        // qDebug () << "Can not find a template for the item" << endl;
+        // qDebug () << "Can not find a template for the item";
     }
 
     return pos;
@@ -244,7 +244,7 @@ CalcPartList TemplKatalogListView::itemsCalcParts( QTreeWidgetItem* it )
 
     FloskelTemplate *flos = static_cast<FloskelTemplate*>( m_dataDict[ it ] );
     if ( flos ) {
-        // qDebug () << "We have calc parts: " << flos->getCalcPartsList().count()<< endl;
+        // qDebug () << "We have calc parts: " << flos->getCalcPartsList().count();
         cpList = flos->getCalcPartsList();
     }
     return cpList;
